pub struct Processor<PM: ProcessorMode> { /* private fields */ }Implementations
Sourceimpl<PM: ProcessorMode> Processor<PM>
impl<PM: ProcessorMode> Processor<PM>
pub fn new( blob_store: Arc<dyn ObjectStore>, pool: ConnectionPool<Core>, config: ProofDataHandlerConfig, commitment_mode: L1BatchCommitmentMode, chain_id: L2ChainId, ) -> Self
pub fn chain_id(&self) -> L2ChainId
pub async fn get_oldest_not_proven_batch( &self, ) -> Result<Option<L1BatchNumber>, ProcessorError>
Sourcepub async fn proof_generation_data_for_existing_batch(
&self,
l1_batch_number: L1BatchNumber,
) -> Result<ProofGenerationData, ProcessorError>
pub async fn proof_generation_data_for_existing_batch( &self, l1_batch_number: L1BatchNumber, ) -> Result<ProofGenerationData, ProcessorError>
Will fetch all the required data for the batch and return it.
Panics
Expects all the data to be present in the database. Will panic if any of the required data is missing.
Sourceimpl Processor<Locking>
impl Processor<Locking>
Sourcepub async fn unlock_batch(
&self,
l1_batch_number: L1BatchNumber,
) -> Result<(), ProcessorError>
pub async fn unlock_batch( &self, l1_batch_number: L1BatchNumber, ) -> Result<(), ProcessorError>
Marks the batch as ‘unpicked’, allowing it to be picked up by another prover.
pub async fn save_proof( &self, l1_batch_id: L1BatchId, proof: L1BatchProofForL1, ) -> Result<(), ProcessorError>
pub async fn save_skipped_proof( &self, l1_batch_id: L1BatchId, ) -> Result<(), ProcessorError>
Sourceimpl Processor<Readonly>
impl Processor<Readonly>
pub async fn get_proof_generation_data( &self, ) -> Result<ProofGenerationData, ProcessorError>
pub async fn verify_proof( &self, l1_batch_number: L1BatchNumber, binary_proof: Vec<u8>, protocol_version: ProtocolSemanticVersion, ) -> Result<(), ProcessorError>